@@ -1,3 +1,4 @@
+// eslint-disable-next-line strict
 module.exports = function(grunt) {
   require('load-grunt-tasks')(grunt);
 
@@ -11,19 +12,6 @@ module.exports = function(grunt) {
       dist: 'dist/**'
     },
 
-    ts: {
-      test: {
-        options: {
-          lib: [
-            'es5',
-            'es2015.promise',
-            'dom'
-          ]
-        },
-        src: ['typings/index.d.ts', 'test/typescript/*.ts']
-      }
-    },
-
     package2bower: {
       all: {
         fields: [
@@ -37,6 +25,10 @@ module.exports = function(grunt) {
       }
     },
 
+    package2env: {
+      all: {}
+    },
+
     usebanner: {
       all: {
         options: {
@@ -70,8 +62,8 @@ module.exports = function(grunt) {
         src: ['test/unit/**/*.js']
       },
       options: {
-        timeout: 30000,
-      },
+        timeout: 30000
+      }
     },
 
     watch: {
@@ -88,12 +80,12 @@ module.exports = function(grunt) {
     webpack: require('./webpack.config.js')
   });
 
-  grunt.registerMultiTask('package2bower', 'Sync package.json to bower.json', function () {
+  grunt.registerMultiTask('package2bower', 'Sync package.json to bower.json', function() {
     var npm = grunt.file.readJSON('package.json');
     var bower = grunt.file.readJSON('bower.json');
     var fields = this.data.fields || [];
 
-    for (var i=0, l=fields.length; i<l; i++) {
+    for (var i = 0, l = fields.length; i < l; i++) {
       var field = fields[i];
       bower[field] = npm[field];
     }
@@ -101,7 +93,17 @@ module.exports = function(grunt) {
     grunt.file.write('bower.json', JSON.stringify(bower, null, 2));
   });
 
-  grunt.registerTask('test', 'Run the jasmine and mocha tests', ['eslint', 'mochaTest', 'karma:single', 'ts']);
+  grunt.registerMultiTask('package2env', 'Sync package.json to env.json', function() {
+    var npm = grunt.file.readJSON('package.json');
+    grunt.file.write('./lib/env/data.js', [
+      'module.exports = ',
+      JSON.stringify({
+        version: npm.version
+      }, null, 2),
+      ';'].join(''));
+  });
+
+  grunt.registerTask('test', 'Run the jasmine and mocha tests', ['eslint', 'mochaTest', 'karma:single']);
   grunt.registerTask('build', 'Run webpack and bundle the source', ['clean', 'webpack']);
-  grunt.registerTask('version', 'Sync version info for a release', ['usebanner', 'package2bower']);
+  grunt.registerTask('version', 'Sync version info for a release', ['usebanner', 'package2bower', 'package2env']);
 };
