@@ -7,6 +7,12 @@ describe('utils::isX', function () {
     expect(utils.isArray({length: 5})).toEqual(false);
   });
 
+  it('should validate Buffer', function () {
+    expect(utils.isBuffer(Buffer.from('a'))).toEqual(true);
+    expect(utils.isBuffer(null)).toEqual(false);
+    expect(utils.isBuffer(undefined)).toEqual(false);
+  });
+
   it('should validate ArrayBuffer', function () {
     expect(utils.isArrayBuffer(new ArrayBuffer(2))).toEqual(true);
     expect(utils.isArrayBuffer({})).toEqual(false);
@@ -41,9 +47,17 @@ describe('utils::isX', function () {
 
   it('should validate Object', function () {
     expect(utils.isObject({})).toEqual(true);
+    expect(utils.isObject([])).toEqual(true);
     expect(utils.isObject(null)).toEqual(false);
   });
 
+  it('should validate plain Object', function () {
+    expect(utils.isPlainObject({})).toEqual(true);
+    expect(utils.isPlainObject([])).toEqual(false);
+    expect(utils.isPlainObject(null)).toEqual(false);
+    expect(utils.isPlainObject(Object.create({}))).toEqual(false);
+  });
+
   it('should validate Date', function () {
     expect(utils.isDate(new Date())).toEqual(true);
     expect(utils.isDate(Date.now())).toEqual(false);
