@@ -8,7 +8,7 @@ import axios, {
   CancelToken,
   CancelTokenSource,
   Canceler
-} from '../../';
+} from 'axios';
 
 const config: AxiosRequestConfig = {
   url: '/user',
@@ -111,6 +111,10 @@ axios.patch('/user', { foo: 'bar' })
   .catch(handleError);
 
 // Typed methods
+interface UserCreationDef {
+    name: string;
+}
+
 interface User {
   id: number;
   name: string;
@@ -138,7 +142,7 @@ axios.get<User>('/user', { params: { id: 12345 } })
 axios.head<User>('/user')
 	.then(handleUserResponse)
     .catch(handleError);
-    
+
 axios.options<User>('/user')
 	.then(handleUserResponse)
 	.catch(handleError);
@@ -147,27 +151,27 @@ axios.delete<User>('/user')
 	.then(handleUserResponse)
 	.catch(handleError);
 
-axios.post<User>('/user', { foo: 'bar' })
+axios.post<User>('/user', { name: 'foo', id: 1 })
 	.then(handleUserResponse)
 	.catch(handleError);
 
-axios.post<User>('/user', { foo: 'bar' }, { headers: { 'X-FOO': 'bar' } })
+axios.post<User>('/user', { name: 'foo', id: 1 }, { headers: { 'X-FOO': 'bar' } })
 	.then(handleUserResponse)
 	.catch(handleError);
 
-axios.put<User>('/user', { foo: 'bar' })
+axios.put<User>('/user', { name: 'foo', id: 1 })
 	.then(handleUserResponse)
 	.catch(handleError);
 
-axios.patch<User>('/user', { foo: 'bar' })
+axios.patch<User>('/user', { name: 'foo', id: 1 })
 	.then(handleUserResponse)
   .catch(handleError);
 
 // (Typed methods) with custom response type
 
 const handleStringResponse = (response: string) => {
-  console.log(response)
-}
+  console.log(response);
+};
 
 axios.get<User, string>('/user?id=12345')
   .then(handleStringResponse)
@@ -189,19 +193,19 @@ axios.delete<User, string>('/user')
   .then(handleStringResponse)
   .catch(handleError);
 
-axios.post<User, string>('/user', { foo: 'bar' })
+axios.post<Partial<UserCreationDef>, string>('/user', { name: 'foo' })
   .then(handleStringResponse)
   .catch(handleError);
 
-axios.post<User, string>('/user', { foo: 'bar' }, { headers: { 'X-FOO': 'bar' } })
+axios.post<Partial<UserCreationDef>, string>('/user', { name: 'foo' }, { headers: { 'X-FOO': 'bar' } })
   .then(handleStringResponse)
   .catch(handleError);
 
-axios.put<User, string>('/user', { foo: 'bar' })
+axios.put<Partial<UserCreationDef>, string>('/user', { name: 'foo' })
   .then(handleStringResponse)
   .catch(handleError);
 
-axios.patch<User, string>('/user', { foo: 'bar' })
+axios.patch<Partial<UserCreationDef>, string>('/user', { name: 'foo' })
   .then(handleStringResponse)
   .catch(handleError);
 
@@ -338,11 +342,11 @@ axios.get('/user')
 
 axios.get('/user')
   .catch((error: any) => 'foo')
-  .then((value: string) => {});
+  .then((value) => {});
 
 axios.get('/user')
   .catch((error: any) => Promise.resolve('foo'))
-  .then((value: string) => {});
+  .then((value) => {});
 
 // Cancellation
 
