@@ -7,6 +7,7 @@ var zlib = require('zlib');
 var assert = require('assert');
 var fs = require('fs');
 var path = require('path');
+var pkg = require('./../../../package.json');
 var server, proxy;
 
 describe('supports http with nodejs', function () {
@@ -17,7 +18,7 @@ describe('supports http with nodejs', function () {
       server = null;
     }
     if (proxy) {
-      proxy.close()
+      proxy.close();
       proxy = null;
     }
     if (process.env.http_proxy) {
@@ -28,6 +29,64 @@ describe('supports http with nodejs', function () {
     }
   });
 
+  it('should throw an error if the timeout property is not parsable as a number', function (done) {
+
+    server = http.createServer(function (req, res) {
+      setTimeout(function () {
+        res.end();
+      }, 1000);
+    }).listen(4444, function () {
+      var success = false, failure = false;
+      var error;
+
+      axios.get('http://localhost:4444/', {
+        timeout: { strangeTimeout: 250 }
+      }).then(function (res) {
+        success = true;
+      }).catch(function (err) {
+        error = err;
+        failure = true;
+      });
+
+      setTimeout(function () {
+        assert.equal(success, false, 'request should not succeed');
+        assert.equal(failure, true, 'request should fail');
+        assert.equal(error.code, 'ERR_PARSE_TIMEOUT');
+        assert.equal(error.message, 'error trying to parse `config.timeout` to int');
+        done();
+      }, 300);
+    });
+  });
+
+  it('should parse the timeout property', function (done) {
+
+    server = http.createServer(function (req, res) {
+      setTimeout(function () {
+        res.end();
+      }, 1000);
+    }).listen(4444, function () {
+      var success = false, failure = false;
+      var error;
+
+      axios.get('http://localhost:4444/', {
+        timeout: '250'
+      }).then(function (res) {
+        success = true;
+      }).catch(function (err) {
+        error = err;
+        failure = true;
+      });
+
+      setTimeout(function () {
+        assert.equal(success, false, 'request should not succeed');
+        assert.equal(failure, true, 'request should fail');
+        assert.equal(error.code, 'ECONNABORTED');
+        assert.equal(error.message, 'timeout of 250ms exceeded');
+        done();
+      }, 300);
+    });
+  });
+
   it('should respect the timeout property', function (done) {
 
     server = http.createServer(function (req, res) {
@@ -57,6 +116,36 @@ describe('supports http with nodejs', function () {
     });
   });
 
+  it('should respect the timeoutErrorMessage property', function (done) {
+
+    server = http.createServer(function (req, res) {
+      setTimeout(function () {
+        res.end();
+      }, 1000);
+    }).listen(4444, function () {
+      var success = false, failure = false;
+      var error;
+
+      axios.get('http://localhost:4444/', {
+        timeout: 250,
+        timeoutErrorMessage: 'oops, timeout',
+      }).then(function (res) {
+        success = true;
+      }).catch(function (err) {
+        error = err;
+        failure = true;
+      });
+
+      setTimeout(function () {
+        assert.strictEqual(success, false, 'request should not succeed');
+        assert.strictEqual(failure, true, 'request should fail');
+        assert.strictEqual(error.code, 'ECONNABORTED');
+        assert.strictEqual(error.message, 'oops, timeout');
+        done();
+      }, 300);
+    });
+  });
+
   it('should allow passing JSON', function (done) {
     var data = {
       firstName: 'Fred',
@@ -65,7 +154,7 @@ describe('supports http with nodejs', function () {
     };
 
     server = http.createServer(function (req, res) {
-      res.setHeader('Content-Type', 'application/json;charset=utf-8');
+      res.setHeader('Content-Type', 'application/json');
       res.end(JSON.stringify(data));
     }).listen(4444, function () {
       axios.get('http://localhost:4444/').then(function (res) {
@@ -83,7 +172,7 @@ describe('supports http with nodejs', function () {
     };
 
     server = http.createServer(function (req, res) {
-      res.setHeader('Content-Type', 'application/json;charset=utf-8');
+      res.setHeader('Content-Type', 'application/json');
       var bomBuffer = Buffer.from([0xEF, 0xBB, 0xBF])
       var jsonBuffer = Buffer.from(JSON.stringify(data));
       res.end(Buffer.concat([bomBuffer, jsonBuffer]));
@@ -188,7 +277,7 @@ describe('supports http with nodejs', function () {
     zlib.gzip(JSON.stringify(data), function (err, zipped) {
 
       server = http.createServer(function (req, res) {
-        res.setHeader('Content-Type', 'application/json;charset=utf-8');
+        res.setHeader('Content-Type', 'application/json');
         res.setHeader('Content-Encoding', 'gzip');
         res.end(zipped);
       }).listen(4444, function () {
@@ -203,7 +292,7 @@ describe('supports http with nodejs', function () {
 
   it('should support gunzip error handling', function (done) {
     server = http.createServer(function (req, res) {
-      res.setHeader('Content-Type', 'application/json;charset=utf-8');
+      res.setHeader('Content-Type', 'application/json');
       res.setHeader('Content-Encoding', 'gzip');
       res.end('invalid response');
     }).listen(4444, function () {
@@ -267,7 +356,7 @@ describe('supports http with nodejs', function () {
       res.end(req.headers.authorization);
     }).listen(4444, function () {
       var auth = { username: 'foo', password: 'bar' };
-      var headers = { Authorization: 'Bearer 1234' };
+      var headers = { AuThOrIzAtIoN: 'Bearer 1234' }; // wonky casing to ensure caseless comparison
       axios.get('http://localhost:4444/', { auth: auth, headers: headers }).then(function (res) {
         var base64 = Buffer.from('foo:bar', 'utf8').toString('base64');
         assert.equal(res.data, 'Basic ' + base64);
@@ -276,6 +365,41 @@ describe('supports http with nodejs', function () {
     });
   });
 
+  it('should provides a default User-Agent header', function (done) {
+    server = http.createServer(function (req, res) {
+      res.end(req.headers['user-agent']);
+    }).listen(4444, function () {
+      axios.get('http://localhost:4444/').then(function (res) {
+        assert.ok(/^axios\/[\d.]+$/.test(res.data), `User-Agent header does not match: ${res.data}`);
+        done();
+      });
+    });
+  });
+
+  it('should allow the User-Agent header to be overridden', function (done) {
+    server = http.createServer(function (req, res) {
+      res.end(req.headers['user-agent']);
+    }).listen(4444, function () {
+      var headers = { 'UsEr-AgEnT': 'foo bar' }; // wonky casing to ensure caseless comparison
+      axios.get('http://localhost:4444/', { headers }).then(function (res) {
+        assert.equal(res.data, 'foo bar');
+        done();
+      });
+    });
+  });
+
+  it('should allow the Content-Length header to be overridden', function (done) {
+    server = http.createServer(function (req, res) {
+      assert.strictEqual(req.headers['content-length'], '42');
+      res.end();
+    }).listen(4444, function () {
+      var headers = { 'CoNtEnT-lEnGtH': '42' }; // wonky casing to ensure caseless comparison
+      axios.post('http://localhost:4444/', 'foo', { headers }).then(function () {
+        done();
+      });
+    });
+  });
+
   it('should support max content length', function (done) {
     var str = Array(100000).join('ж');
 
@@ -362,13 +486,27 @@ describe('supports http with nodejs', function () {
       setTimeout(function () {
         assert.equal(success, false, 'request should not succeed');
         assert.equal(failure, true, 'request should fail');
-        assert.equal(error.code, 'ERR_FR_MAX_BODY_LENGTH_EXCEEDED');
         assert.equal(error.message, 'Request body larger than maxBodyLength limit');
         done();
       }, 100);
     });
   });
 
+  it('should display error while parsing params', function (done) {
+    server = http.createServer(function () {
+      
+    }).listen(4444, function () {
+      axios.get('http://localhost:4444/', {
+        params: {
+          errorParam: new Date(undefined),
+        },
+      }).catch(function (err) {
+        assert.deepEqual(err.exists, true)
+        done();
+      });
+    });
+  });
+
   it('should support sockets', function (done) {
     // Different sockets for win32 vs darwin/linux
     var socketName = './test.sock';
@@ -859,7 +997,7 @@ describe('supports http with nodejs', function () {
       axios.get('http://localhost:4444/', {
         cancelToken: source.token
       }).catch(function (thrown) {
-        assert.ok(thrown instanceof axios.Cancel, 'Promise must be rejected with a Cancel obejct');
+        assert.ok(thrown instanceof axios.Cancel, 'Promise must be rejected with a Cancel object');
         assert.equal(thrown.message, 'Operation has been canceled.');
         done();
       });
@@ -879,5 +1017,66 @@ describe('supports http with nodejs', function () {
       });
     });
   });
+
+  it('should supply a user-agent if one is not specified', function (done) {
+    server = http.createServer(function (req, res) {
+      assert.equal(req.headers["user-agent"], 'axios/' + pkg.version);
+      res.end();
+    }).listen(4444, function () {
+      axios.get('http://localhost:4444/'
+      ).then(function (res) {
+        done();
+      });
+    });
+  });
+
+  it('should omit a user-agent if one is explicitly disclaimed', function (done) {
+    server = http.createServer(function (req, res) {
+      assert.equal("user-agent" in req.headers, false);
+      assert.equal("User-Agent" in req.headers, false);
+      res.end();
+    }).listen(4444, function () {
+      axios.get('http://localhost:4444/', {
+        headers: {
+          "User-Agent": null
+        }
+      }
+      ).then(function (res) {
+        done();
+      });
+    });
+  });
+
+  it('should throw an error if http server that aborts a chunked request', function (done) {
+    server = http.createServer(function (req, res) {
+      res.writeHead(200, { 'Content-Type': 'text/plain' });
+      res.write('chunk 1');
+      setTimeout(function () {
+        res.write('chunk 2');
+      }, 100);
+      setTimeout(function() {
+        res.destroy();
+      }, 200);
+    }).listen(4444, function () {
+      var success = false, failure = false;
+      var error;
+
+      axios.get('http://localhost:4444/aborted', {
+        timeout: 500
+      }).then(function (res) {
+        success = true;
+      }).catch(function (err) {
+        error = err;
+        failure = true;
+      }).finally(function () {
+        assert.strictEqual(success, false, 'request should not succeed');
+        assert.strictEqual(failure, true, 'request should fail');
+        assert.strictEqual(error.code, 'ERR_REQUEST_ABORTED');
+        assert.strictEqual(error.message, 'error request aborted');
+        done();
+      });
+    });
+  });
+
 });
 
